Sandro Bonazzola has uploaded a new change for review.

Change subject: packaging: setup: fixing the check of ISO image permission
......................................................................

packaging: setup: fixing the check of ISO image permission

Fixing ISO image permission check against qemu user

Change-Id: I3445e536f4f22b7ccdad1163b4be8afe1c8a69af
Bug-Url: https://bugzilla.redhat.com/1181585
Signed-off-by: Simone Tiraboschi <stira...@redhat.com>
(cherry picked from commit 4c2ffae5bdeaf311c120711f1049f820abff2259)
---
M src/plugins/ovirt-hosted-engine-setup/vm/boot_cdrom.py
1 file changed, 2 insertions(+), 4 deletions(-)


  git pull ssh://gerrit.ovirt.org:29418/ovirt-hosted-engine-setup 
refs/changes/38/36838/1

diff --git a/src/plugins/ovirt-hosted-engine-setup/vm/boot_cdrom.py 
b/src/plugins/ovirt-hosted-engine-setup/vm/boot_cdrom.py
index 605c36c..6a72b90 100644
--- a/src/plugins/ovirt-hosted-engine-setup/vm/boot_cdrom.py
+++ b/src/plugins/ovirt-hosted-engine-setup/vm/boot_cdrom.py
@@ -73,15 +73,13 @@
                 readable = True
         else:
             # iso images may be on existing ISO domains and must be readable
             # by vdsm user
             try:
                 self.execute(
                     (
                         self.command.get('sudo'),
                         '-u',
-                        'vdsm',
-                        '-g',
-                        'kvm',
+                        'qemu',
                         'test',
                         '-r',
                         realpath,
@@ -73,15 +73,13 @@
         else:
             # iso images may be on existing ISO domains and must be readable
-            # by vdsm user
+            # by qemu user
             try:
                 self.execute(


-- 
To view, visit http://gerrit.ovirt.org/36838
To unsubscribe, visit http://gerrit.ovirt.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I3445e536f4f22b7ccdad1163b4be8afe1c8a69af
Gerrit-PatchSet: 1
Gerrit-Project: ovirt-hosted-engine-setup
Gerrit-Branch: ovirt-hosted-engine-setup-1.2
Gerrit-Owner: Sandro Bonazzola <sbona...@redhat.com>
Gerrit-Reviewer: Simone Tiraboschi <stira...@redhat.com>
_______________________________________________
Engine-patches mailing list
Engine-patches@ovirt.org
http://lists.ovirt.org/mailman/listinfo/engine-patches

Reply via email to